==> DSA_1.0.tar.gz: DSA/src/getCVrisk.c <==
#include <stdlib.h>
#include <stdio.h>
#include <math.h>
#include <float.h>

/**
#include <nag.h>
#include <nagg02.h>
**/
#include <R.h>
#include <R_ext/Utils.h>
#include <Rmath.h>
#include "dsa.h"

void DSA_PACK_getaverageCVrisks(int *gCOUNT,int *gCONST,int *sx,double *Xtrain,double *Ytrain,
				double *Xval,double *Yval,int **bestmodels,double *tempXtrain,
				double *tempYtrain,double *tempXval,
				double *tempYval,double *temptermtrain,double *temptermval,double *PARA,
				double *SE, double *COV,double *RES, double *glmWT,
				double *CVrisksbysplit,double *WTtrain,double *WTval,int nforced,
				int *tempmodel,	double* new_coefficients,double* WX, double* Z, 
				double* qraux, double* effects, double* work, int* pivot)
{
  int IP,msize,maxsize,ntrain,nval,nvarX,fold,kk,i,nglmcall,CENSOR,orderint,maxorderint,NnonNA,binind,*Pmodel;
  double temprss;

  /* INITIALIZATION */
  msize = gCOUNT[0];
  orderint = gCOUNT[1];
  nglmcall = gCOUNT[2];
  fold = gCOUNT[3];
  ntrain = gCOUNT[4];
  nval = gCOUNT[5];

  maxsize = gCONST[0];
  nvarX = gCONST[5];
  CENSOR = gCONST[6];
  maxorderint = gCONST[1];
  binind = gCONST[9];

  if(DSA_PACK_userMlevel>=DSA_PACK_Mhigh)
    {
      Rprintf("orderint: %ld and maxorderint: %ld\n",orderint,maxorderint);
      Rprintf("msize is: %li\n",(msize+1));
    }

  /* GET CV RISK FOR EACH MODEL SIZE */
  for(kk=0;kk<nforced;kk++)CVrisksbysplit[fold*(maxsize+1)+kk]=R_PosInf;
  for(kk=msize+1;kk<maxsize+1;kk++)CVrisksbysplit[fold*(maxsize+1)+kk]=R_PosInf;

  for(kk=nforced;kk<(msize+1);kk++)
    {
      /*FIT MODELS ON TRAINING SET*/
      IP = kk + 1;
      temprss=R_PosInf;
      if(kk==0)
	{
	  Pmodel=tempmodel;
	  DSA_PACK_initialize_l(Pmodel,maxsize*nvarX);
	}
      else Pmodel=bestmodels[kk-1];
      DSA_PACK_evaluatenewmodel(sx,maxsize,kk,Pmodel,-1,Pmodel,nvarX,ntrain,tempXtrain,Xtrain,temptermtrain,
				CENSOR,glmWT,WTtrain,IP,tempYtrain,Ytrain,PARA,SE,COV,RES,&nglmcall,
				&temprss,Pmodel,1,binind,
				new_coefficients, WX,  Z,  qraux, effects, work, pivot
				);

      /*Get DATA FROM VALIDATION SET*/
      DSA_PACK_gettempXdata(kk,Pmodel,maxsize,nvarX,nval,tempXval,Xval,temptermval,tempYval,Yval);
      DSA_PACK_getglmWT_excludeNA(nval,glmWT,tempXval,tempYval,kk,maxsize,&NnonNA,CENSOR,WTval);

      /* GET CV ON VALIDATION SET */
      if(binind==1)
	{
	  temprss=DSA_PACK_getarss(nval,tempXval,maxsize,kk+1,tempYval,glmWT,PARA,2);
	  temprss/=NnonNA;
	  if(DSA_PACK_userMlevel>=DSA_PACK_Mmedium)
	    {
	      Rprintf("\nCoef on training:\n");
	      for(i=0;i<kk+1;i++)Rprintf("%lf ",*(PARA+i));
	      Rprintf("\nNnonNA: %li\n",NnonNA);
	    }
	}
      else
	{
	  temprss=DSA_PACK_getarss(nval,tempXval,maxsize,kk+1,tempYval,glmWT,PARA,1);
	  temprss/=NnonNA;
	  if(DSA_PACK_userMlevel>=DSA_PACK_Mmedium)
	    {
	      Rprintf("\nCoef on training:\n");
	      for(i=0;i<kk+1;i++)Rprintf("%lf ",*(PARA+i));
	    }
	}
      if(DSA_PACK_userMlevel>=DSA_PACK_Mmedium)Rprintf("\nFor k=%ld, cvrisk=%lf \n",kk,temprss);
      CVrisksbysplit[fold*(maxsize+1)+kk] = temprss;

    }

  gCOUNT[2] = nglmcall;
}

==> DSA_2.0.2.tar.gz: DSA/src/getCVrisk.c <==
#include <stdlib.h>
#include <stdio.h>
#include <math.h>
#include <float.h>

/**
#include <nag.h>
#include <nagg02.h>
**/
#include <R.h>
#include <R_ext/Utils.h>
#include <Rmath.h>
#include "dsa.h"

void DSA_PACK_getaverageCVrisks(int *gCOUNT,int *gCONST,int *sx,double *Xtrain,double *Ytrain,
				double *Xval,double *Yval,int **bestmodels,double *tempXtrain,
				double *tempYtrain,double *tempXval,
				double *tempYval,double *temptermtrain,double *temptermval,double *PARA,
				double *SE, double *COV,double *RES, double *glmWT,
				double *CVrisksbysplit,double *WTtrain,double *WTval,int nforced,
				int *tempmodel,	double* new_coefficients,double* WX, double* Z, 
				double* qraux, double* effects, double* work, int* pivot,double *binWTtrain,
				double *binWTval)
{
  int IP,msize,maxsize,ntrain,nval,nvarX,fold,kk,i,nglmcall,CENSOR,orderint,maxorderint,NnonNA,binind,*Pmodel;
  double temprss;

  /* INITIALIZATION */
  msize = gCOUNT[0];
  orderint = gCOUNT[1];
  nglmcall = gCOUNT[2];
  fold = gCOUNT[3];
  ntrain = gCOUNT[4];
  nval = gCOUNT[5];

  maxsize = gCONST[0];
  nvarX = gCONST[5];
  CENSOR = gCONST[6];
  maxorderint = gCONST[1];
  binind = gCONST[9];

  if(DSA_PACK_userMlevel>=DSA_PACK_Mhigh)
    {
      Rprintf("orderint: %ld and maxorderint: %ld\n",orderint,maxorderint);
      Rprintf("msize is: %li\n",(msize+1));
    }

  /* GET CV RISK FOR EACH MODEL SIZE */
  for(kk=0;kk<nforced;kk++)CVrisksbysplit[fold*(maxsize+1)+kk]=R_PosInf;
  for(kk=msize+1;kk<maxsize+1;kk++)CVrisksbysplit[fold*(maxsize+1)+kk]=R_PosInf;

  for(kk=nforced;kk<(msize+1);kk++)
    {
      /*FIT MODELS ON TRAINING SET*/
      IP = kk + 1;
      temprss=R_PosInf;
      if(kk==0)
	{
	  Pmodel=tempmodel;
	  DSA_PACK_initialize_l(Pmodel,maxsize*nvarX);
	}
      else Pmodel=bestmodels[kk-1];
      DSA_PACK_evaluatenewmodel(sx,maxsize,kk,Pmodel,-1,Pmodel,nvarX,ntrain,tempXtrain,Xtrain,temptermtrain,
				CENSOR,glmWT,WTtrain,IP,tempYtrain,Ytrain,PARA,SE,COV,RES,&nglmcall,
				&temprss,Pmodel,1,binind,
				new_coefficients, WX,  Z,  qraux, effects, work, pivot,binWTtrain
				);

      /*Get DATA FROM VALIDATION SET*/
      DSA_PACK_gettempXdata(kk,Pmodel,maxsize,nvarX,nval,tempXval,Xval,temptermval,tempYval,Yval);
      DSA_PACK_getglmWT_excludeNA(nval,glmWT,tempXval,tempYval,kk,maxsize,&NnonNA,CENSOR,WTval);

      /* GET CV ON VALIDATION SET */
      if(binind==1)
	{
	  temprss=DSA_PACK_getarss(nval,tempXval,maxsize,kk+1,tempYval,glmWT,PARA,2,binWTval);
	  temprss/=NnonNA;
	  if(DSA_PACK_userMlevel>=DSA_PACK_Mmedium)
	    {
	      Rprintf("\nCoef on training:\n");
	      for(i=0;i<kk+1;i++)Rprintf("%lf ",*(PARA+i));
	      Rprintf("\nNnonNA: %li\n",NnonNA);
	    }
	}
      else
	{
	  temprss=DSA_PACK_getarss(nval,tempXval,maxsize,kk+1,tempYval,glmWT,PARA,1,binWTval);
	  temprss/=NnonNA;
	  if(DSA_PACK_userMlevel>=DSA_PACK_Mmedium)
	    {
	      Rprintf("\nCoef on training:\n");
	      for(i=0;i<kk+1;i++)Rprintf("%lf ",*(PARA+i));
	    }
	}
      if(DSA_PACK_userMlevel>=DSA_PACK_Mmedium)Rprintf("\nFor k=%ld, cvrisk=%lf \n",kk,temprss);
      CVrisksbysplit[fold*(maxsize+1)+kk] = temprss;

    }

  gCOUNT[2] = nglmcall;
}
